@@ -49,6 +49,7 @@ from .type_defs import (
     DescribeProgramResponseTypeDef,
     DescribeSourceLocationResponseTypeDef,
     DescribeVodSourceResponseTypeDef,
+    EmptyResponseMetadataTypeDef,
     GetChannelPolicyResponseTypeDef,
     GetChannelScheduleResponseTypeDef,
     GetPlaybackConfigurationResponseTypeDef,
@@ -125,6 +126,14 @@ class MediaTailorClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#close)
+        """
+
     def configure_logs_for_playback_configuration(
         self, *, PercentEnabled: int, PlaybackConfigurationName: str
     ) -> ConfigureLogsForPlaybackConfigurationResponseTypeDef:
@@ -139,9 +148,9 @@ class MediaTailorClient(BaseClient):
         self,
         *,
         ChannelName: str,
-        Outputs: Sequence["RequestOutputItemTypeDef"],
+        Outputs: Sequence[RequestOutputItemTypeDef],
         PlaybackMode: PlaybackModeType,
-        FillerSlate: "SlateSourceTypeDef" = ...,
+        FillerSlate: SlateSourceTypeDef = ...,
         Tags: Mapping[str, str] = ...,
         Tier: TierType = ...
     ) -> CreateChannelResponseTypeDef:
@@ -155,7 +164,7 @@ class MediaTailorClient(BaseClient):
     def create_live_source(
         self,
         *,
-        HttpPackageConfigurations: Sequence["HttpPackageConfigurationTypeDef"],
+        HttpPackageConfigurations: Sequence[HttpPackageConfigurationTypeDef],
         LiveSourceName: str,
         SourceLocationName: str,
         Tags: Mapping[str, str] = ...
@@ -170,10 +179,10 @@ class MediaTailorClient(BaseClient):
     def create_prefetch_schedule(
         self,
         *,
-        Consumption: "PrefetchConsumptionTypeDef",
+        Consumption: PrefetchConsumptionTypeDef,
         Name: str,
         PlaybackConfigurationName: str,
-        Retrieval: "PrefetchRetrievalTypeDef",
+        Retrieval: PrefetchRetrievalTypeDef,
         StreamId: str = ...
     ) -> CreatePrefetchScheduleResponseTypeDef:
         """
@@ -188,9 +197,9 @@ class MediaTailorClient(BaseClient):
         *,
         ChannelName: str,
         ProgramName: str,
-        ScheduleConfiguration: "ScheduleConfigurationTypeDef",
+        ScheduleConfiguration: ScheduleConfigurationTypeDef,
         SourceLocationName: str,
-        AdBreaks: Sequence["AdBreakTypeDef"] = ...,
+        AdBreaks: Sequence[AdBreakTypeDef] = ...,
         LiveSourceName: str = ...,
         VodSourceName: str = ...
     ) -> CreateProgramResponseTypeDef:
@@ -204,11 +213,11 @@ class MediaTailorClient(BaseClient):
     def create_source_location(
         self,
         *,
-        HttpConfiguration: "HttpConfigurationTypeDef",
+        HttpConfiguration: HttpConfigurationTypeDef,
         SourceLocationName: str,
-        AccessConfiguration: "AccessConfigurationTypeDef" = ...,
-        DefaultSegmentDeliveryConfiguration: "DefaultSegmentDeliveryConfigurationTypeDef" = ...,
-        SegmentDeliveryConfigurations: Sequence["SegmentDeliveryConfigurationTypeDef"] = ...,
+        AccessConfiguration: AccessConfigurationTypeDef = ...,
+        DefaultSegmentDeliveryConfiguration: DefaultSegmentDeliveryConfigurationTypeDef = ...,
+        SegmentDeliveryConfigurations: Sequence[SegmentDeliveryConfigurationTypeDef] = ...,
         Tags: Mapping[str, str] = ...
     ) -> CreateSourceLocationResponseTypeDef:
         """
@@ -221,7 +230,7 @@ class MediaTailorClient(BaseClient):
     def create_vod_source(
         self,
         *,
-        HttpPackageConfigurations: Sequence["HttpPackageConfigurationTypeDef"],
+        HttpPackageConfigurations: Sequence[HttpPackageConfigurationTypeDef],
         SourceLocationName: str,
         VodSourceName: str,
         Tags: Mapping[str, str] = ...
@@ -500,13 +509,13 @@ class MediaTailorClient(BaseClient):
         self,
         *,
         AdDecisionServerUrl: str = ...,
-        AvailSuppression: "AvailSuppressionTypeDef" = ...,
-        Bumper: "BumperTypeDef" = ...,
-        CdnConfiguration: "CdnConfigurationTypeDef" = ...,
+        AvailSuppression: AvailSuppressionTypeDef = ...,
+        Bumper: BumperTypeDef = ...,
+        CdnConfiguration: CdnConfigurationTypeDef = ...,
         ConfigurationAliases: Mapping[str, Mapping[str, str]] = ...,
-        DashConfiguration: "DashConfigurationForPutTypeDef" = ...,
-        LivePreRollConfiguration: "LivePreRollConfigurationTypeDef" = ...,
-        ManifestProcessingRules: "ManifestProcessingRulesTypeDef" = ...,
+        DashConfiguration: DashConfigurationForPutTypeDef = ...,
+        LivePreRollConfiguration: LivePreRollConfigurationTypeDef = ...,
+        ManifestProcessingRules: ManifestProcessingRulesTypeDef = ...,
         Name: str = ...,
         PersonalizationThresholdSeconds: int = ...,
         SlateAdUrl: str = ...,
@@ -537,7 +546,9 @@ class MediaTailorClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#stop_channel)
         """
 
-    def tag_resource(self, *, ResourceArn: str, Tags: Mapping[str, str]) -> None:
+    def tag_resource(
+        self, *, ResourceArn: str, Tags: Mapping[str, str]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Adds tags to the specified playback configuration resource.
 
@@ -545,7 +556,9 @@ class MediaTailorClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#tag_resource)
         """
 
-    def untag_resource(self, *, ResourceArn: str, TagKeys: Sequence[str]) -> None:
+    def untag_resource(
+        self, *, ResourceArn: str, TagKeys: Sequence[str]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Removes tags from the specified playback configuration resource.
 
@@ -557,8 +570,8 @@ class MediaTailorClient(BaseClient):
         self,
         *,
         ChannelName: str,
-        Outputs: Sequence["RequestOutputItemTypeDef"],
-        FillerSlate: "SlateSourceTypeDef" = ...
+        Outputs: Sequence[RequestOutputItemTypeDef],
+        FillerSlate: SlateSourceTypeDef = ...
     ) -> UpdateChannelResponseTypeDef:
         """
         Updates an existing channel.
@@ -570,7 +583,7 @@ class MediaTailorClient(BaseClient):
     def update_live_source(
         self,
         *,
-        HttpPackageConfigurations: Sequence["HttpPackageConfigurationTypeDef"],
+        HttpPackageConfigurations: Sequence[HttpPackageConfigurationTypeDef],
         LiveSourceName: str,
         SourceLocationName: str
     ) -> UpdateLiveSourceResponseTypeDef:
@@ -584,11 +597,11 @@ class MediaTailorClient(BaseClient):
     def update_source_location(
         self,
         *,
-        HttpConfiguration: "HttpConfigurationTypeDef",
+        HttpConfiguration: HttpConfigurationTypeDef,
         SourceLocationName: str,
-        AccessConfiguration: "AccessConfigurationTypeDef" = ...,
-        DefaultSegmentDeliveryConfiguration: "DefaultSegmentDeliveryConfigurationTypeDef" = ...,
-        SegmentDeliveryConfigurations: Sequence["SegmentDeliveryConfigurationTypeDef"] = ...
+        AccessConfiguration: AccessConfigurationTypeDef = ...,
+        DefaultSegmentDeliveryConfiguration: DefaultSegmentDeliveryConfigurationTypeDef = ...,
+        SegmentDeliveryConfigurations: Sequence[SegmentDeliveryConfigurationTypeDef] = ...
     ) -> UpdateSourceLocationResponseTypeDef:
         """
         Updates a source location on a specific channel.
@@ -600,7 +613,7 @@ class MediaTailorClient(BaseClient):
     def update_vod_source(
         self,
         *,
-        HttpPackageConfigurations: Sequence["HttpPackageConfigurationTypeDef"],
+        HttpPackageConfigurations: Sequence[HttpPackageConfigurationTypeDef],
         SourceLocationName: str,
         VodSourceName: str
     ) -> UpdateVodSourceResponseTypeDef:
